@@ -21,7 +21,7 @@ class Minify(object):
     def __init__(
         self, app=None, html=True, js=True, cssless=True,
         fail_safe=True, bypass=[], bypass_caching=[], caching_limit=2,
-        passive=False, static=True
+        passive=False, static=True, script_types=[]
     ):
         ''' Extension to minify flask response for html, javascript, css and less.
 
@@ -45,6 +45,8 @@ class Minify(object):
             to disable active minifying.
         static: bool
             to enable minifying static files css, less and js.
+        script_types: list
+            list of script types to limit js minification to.
 
         Notes
         -----
@@ -65,9 +67,13 @@ class Minify(object):
         to bypass all routes on a certain blueprint you can just pass
         the pattern as such:
             minify(app, bypass=['blueprint_name.*'])
+
+        when using `script_types` include '' (empty string) in the list to
+        include script blocks which are missing the type attribute.
         '''
         self.html = html
         self.js = js
+        self.script_types = script_types
         self.cssless = cssless
         self.fail_safe = fail_safe
         self.bypass = bypass
@@ -101,7 +107,12 @@ class Minify(object):
             the current endpoint.
         '''
         with self.app.app_context():
-            return getattr(request, 'endpoint', '') or ''
+            path = getattr(request, 'endpoint', '') or ''
+
+            if path == 'static':
+                path = getattr(request, 'path', '') or ''
+
+            return path
 
     def init_app(self, app):
         ''' Handle initiation of multiple apps NOTE:Factory Method'''
@@ -115,7 +126,7 @@ class Minify(object):
     @classmethod
     def get_minified(cls, content, tag, fail_safe=False,
                      only_html_content=False, html_cssless=False,
-                     html_js=False):
+                     html_js=False, script_types=[]):
         ''' To minify css/less or javascript and failsafe that.
 
         Parameters
@@ -132,6 +143,8 @@ class Minify(object):
             to minify html inner css/less.
         html_js: bool
             to minify html inner js.
+        script_types: list
+            list of script types to limit js minification to.
 
         Returns
         -------
@@ -150,14 +163,20 @@ class Minify(object):
                 for tag, enabled in iter_tags_to_minify(html_cssless,
                                                         html_js):
                     if enabled:
-                        for sub_content in get_tag_contents(content, tag):
+                        for sub_content in get_tag_contents(content,
+                                                            tag,
+                                                            script_types):
                             content = content.replace(sub_content,
                                                       cls.get_minified(
                                                           sub_content,
                                                           tag,
-                                                          fail_safe))
+                                                          fail_safe,
+                                                          script_types))
 
-                return content if only_html_content else minify_html(content)
+                return content if only_html_content else minify_html(
+                    content,
+                    remove_comments=True,
+                    remove_optional_attribute_quotes=False)
             else:
                 raise AttributeError('Unknown HTML tag')
 
@@ -182,7 +201,7 @@ class Minify(object):
         '''
         matches = [compiled_pattern for compiled_pattern in
                    [compile_re(pattern) for pattern in patterns]
-                   if compiled_pattern.match(self.endpoint)]
+                   if compiled_pattern.search(self.endpoint)]
 
         return matches
 
@@ -217,7 +236,8 @@ class Minify(object):
                                      self.fail_safe,
                                      not self.html,
                                      self.cssless,
-                                     self.js)
+                                     self.js,
+                                     self.script_types)
 
         if not _cached() and not bypassed:
             if limit_reached and _cache_dict():
